@@ -22,6 +22,10 @@
 #ifndef __MDFN_CDAFREADER_SF_H
 #define __MDFN_CDAFREADER_SF_H
 
+namespace Mednafen
+{
+
 CDAFReader* CDAFR_SF_Open(Stream* fp);
 
+}
 #endif
