@@ -1,6 +1,11 @@
 #ifndef __MDFN_CHEAT_FORMATS_GB_H
 #define __MDFN_CHEAT_FORMATS_GB_H
 
+namespace Mednafen
+{
+
 extern const std::vector<CheatFormatStruct> CheatFormats_GB;
 
+}
+
 #endif
