@@ -1,6 +1,10 @@
 #ifndef __MDFN_CHEAT_FORMATS_SNES_H
 #define __MDFN_CHEAT_FORMATS_SNES_H
 
+namespace Mednafen
+{
+
 extern const std::vector<CheatFormatStruct> CheatFormats_SNES;
 
+}
 #endif
