@@ -25,8 +25,11 @@
 #include "ZLInflateFilter.h"
 #include <mednafen/mednafen.h>
 
-ZLInflateFilter::ZLInflateFilter(Stream *source_stream, const std::string& vfp, FORMAT df, uint64 csize, uint64 ucs, uint64 ucrc32) 
-	: ss(source_stream), ss_startpos(source_stream->tell()), ss_boundpos(ss_startpos + csize), ss_pos(ss_startpos), uc_size(ucs), running_crc32(0), expected_crc32(ucrc32), vfpath(vfp)
+namespace Mednafen
+{
+
+ZLInflateFilter::ZLInflateFilter(Stream *source_stream, const std::string& vfc, FORMAT df, uint64 csize, uint64 ucs, uint64 ucrc32) 
+	: ss(source_stream), ss_startpos(source_stream->tell()), ss_boundpos(ss_startpos + csize), ss_pos(ss_startpos), uc_size(ucs), running_crc32(0), expected_crc32(ucrc32), vfcontext(vfc)
 {
  int irc;
  int iiwbits;
@@ -61,6 +64,7 @@ ZLInflateFilter::ZLInflateFilter(Stream *source_stream, const std::string& vfp,
   throw MDFN_Error(0, _("zlib inflateInit2() failed: %d"), irc);
 
  position = 0;
+ target_position = 0;
 }
 
 ZLInflateFilter::~ZLInflateFilter()
@@ -75,13 +79,21 @@ ZLInflateFilter::~ZLInflateFilter()
  }
 }
 
-uint64 ZLInflateFilter::read(void *data, uint64 count, bool error_on_eos)
+uint64 ZLInflateFilter::read_real(void *data, uint64 count, bool error_on_eos)
 {
+ //printf("ZLInflateFilter::read() %llu --- %llu %llu %llu --- %016llx %016llx\n", (unsigned long long)count, (unsigned long long)ss->tell(), (unsigned long long)ss_startpos, (unsigned long long)position, (unsigned long long)this, (unsigned long long)ss);
+
+ if(ss->tell() != (ss_startpos + position))
+  ss->seek(ss_startpos + position, SEEK_SET);
+ //
+ //
  const uint64 count_limited = std::min<uint64>(uc_size - position, count);
 
  zs.next_out = (Bytef*)data;
  zs.avail_out = count_limited;
 
+ bool stream_end = false;
+
  while((uint64)(zs.next_out - (Bytef*)data) < count_limited)
  {
   if(!zs.avail_in)
@@ -95,19 +107,40 @@ uint64 ZLInflateFilter::read(void *data, uint64 count, bool error_on_eos)
    zs.avail_in = rc;
   }
 
-  bool no_more_input = !zs.avail_in;
+  if(stream_end)
+  {
+   if(zs.avail_in)
+   {
+    //printf("inflateReset: %u\n", (unsigned)zs.avail_in);
+
+    int reset_irc = inflateReset(&zs);
+
+    //printf("inflateResetPost: %u\n", (unsigned)zs.avail_in);
+
+    if(MDFN_UNLIKELY(reset_irc < 0))
+     throw MDFN_Error(0, _("Error reading from %s: inflateReset() failed: %d"), vfcontext.c_str(), reset_irc);
+
+    stream_end = false;
+   }
+   else
+    break;
+  }
+
+  const bool no_more_input = !zs.avail_in;
   int irc;
 
   zs.total_out = 0;
+  //printf("inflate: stream_end=%d, zs.avail_in=%d\n", stream_end, zs.avail_in);
   irc = inflate(&zs, no_more_input ? Z_SYNC_FLUSH : Z_NO_FLUSH);
+  //printf(" return: %d\n", irc);
   if(MDFN_UNLIKELY(irc < 0))
   {
    if(irc == Z_DATA_ERROR)
-    throw MDFN_Error(0, _("Error reading from virtual file \"%s\": %s"), vfpath.c_str(), zs.msg);
+    throw MDFN_Error(0, _("Error reading from %s: %s"), vfcontext.c_str(), zs.msg);
    else if(irc == Z_MEM_ERROR)
-    throw MDFN_Error(0, _("Error reading from virtual file \"%s\": %s"), vfpath.c_str(), _("insufficient memory"));
+    throw MDFN_Error(0, _("Error reading from %s: %s"), vfcontext.c_str(), _("insufficient memory"));
    else
-    throw MDFN_Error(0, _("Error reading from virtual file \"%s\": zlib error %d"), vfpath.c_str(), irc);
+    throw MDFN_Error(0, _("Error reading from %s: zlib error %d"), vfcontext.c_str(), irc);
   }
   position += zs.total_out;
 
@@ -115,9 +148,10 @@ uint64 ZLInflateFilter::read(void *data, uint64 count, bool error_on_eos)
   {
    //if(irc != Z_STREAM_END)
    // throw MDFN_Error(0, _("Ran out of data for inflate(), but not at
-
    break;
   }
+  else if(irc == Z_STREAM_END)
+   stream_end = true;
  }
 
  uint64 ret = zs.next_out - (Bytef*)data;
@@ -132,12 +166,51 @@ uint64 ZLInflateFilter::read(void *data, uint64 count, bool error_on_eos)
   if(position == uc_size)
   {
    if(running_crc32 != expected_crc32)
-    throw MDFN_Error(0, _("Error reading from virtual file \"%s\": %s"), vfpath.c_str(), _("decompressed data fails CRC32 check"));
+    throw MDFN_Error(0, _("Error reading from %s: %s"), vfcontext.c_str(), _("decompressed data fails CRC32 check"));
   }
  }
 
  if(MDFN_UNLIKELY(ret < count && error_on_eos))
-  throw MDFN_Error(0, _("Error reading from virtual file \"%s\": %s"), vfpath.c_str(), _("Unexpected EOF"));
+  throw MDFN_Error(0, _("Error reading from %s: %s"), vfcontext.c_str(), _("Unexpected EOF"));
+
+ return ret;
+}
+
+uint64 ZLInflateFilter::read(void *data, uint64 count, bool error_on_eos)
+{
+ if(!count)
+  return 0;
+
+ if(target_position < position)
+ {
+  //puts("REWIND");
+  ss->seek(ss_startpos, SEEK_SET);
+  ss_pos = ss_startpos;
+  position = 0;
+  running_crc32 = 0;
+  //
+  zs.avail_in = 0;
+  //
+  int irc = inflateReset(&zs);
+
+  if(MDFN_UNLIKELY(irc < 0))
+   throw MDFN_Error(0, _("Error seeking in %s: inflateReset() failed: %d"), vfcontext.c_str(), irc);
+ }
+
+ while(position < target_position)
+ {
+  //puts("Seek forward");
+  uint8 dummy[4096];
+  uint64 toread = std::min<uint64>(target_position - position, sizeof(dummy));
+
+  if(MDFN_UNLIKELY(read_real(dummy, toread, false) != toread))
+   throw MDFN_Error(EINVAL, _("Error seeking in %s: Ran out of data while seeking to position %llu in deflate-compressed stream."), vfcontext.c_str(), (unsigned long long)target_position);
+ }
+ //
+ //
+ uint64 ret = read_real(data, count, error_on_eos);
+
+ target_position = position;
 
  return ret;
 }
@@ -162,54 +235,40 @@ void ZLInflateFilter::seek(int64 offset, int whence)
         break;
 
    case SEEK_CUR:
-        new_position = position + offset;
+        new_position = target_position + offset;
         break;
 
    case SEEK_END:
-	if(MDFN_UNLIKELY(uc_size == ~(uint64)0))
-         throw MDFN_Error(EINVAL, _("Error seeking in virtual file \"%s\": %s"), vfpath.c_str(), _("Attempted to seek relative to end-of-file in deflate-compressed stream of indeterminate uncompressed size."));
-	else
-	 new_position = uc_size + offset;
+	new_position = size() + offset;
         break;
  }
 
- if(MDFN_UNLIKELY((int64)new_position < 0 || new_position > uc_size))
-  throw MDFN_Error(EINVAL, _("Error seeking in virtual file \"%s\": Attempted to seek to out-of-bounds position %llu in deflate-compressed stream."), vfpath.c_str(), (unsigned long long)new_position);
+ if(MDFN_UNLIKELY((int64)new_position < 0))
+  throw MDFN_Error(EINVAL, _("Error seeking in %s: Attempted to seek to out-of-bounds position %llu in deflate-compressed stream."), vfcontext.c_str(), (unsigned long long)new_position);
 
- if(new_position < position)
- {
-  int irc = inflateReset(&zs);
-
-  if(MDFN_UNLIKELY(irc < 0))
-   throw MDFN_Error(0, _("Error seeking in virtual file \"%s\": inflateReset() failed: %d"), vfpath.c_str(), irc);
-
-  ss->seek(ss_startpos, SEEK_SET);
-  ss_pos = ss_startpos;
-  position = 0;
-  running_crc32 = 0;
- }
-
- while(position < new_position)
- {
-  uint8 dummy[4096];
-  uint64 toread = std::min<uint64>(new_position - position, sizeof(dummy));
-
-  if(MDFN_UNLIKELY(read(dummy, toread, false) != toread))
-   throw MDFN_Error(EINVAL, _("Error seeking in virtual file \"%s\": Ran out of data while seeking to position %llu in deflate-compressed stream."), vfpath.c_str(), (unsigned long long)new_position);
- }
+ target_position = new_position;
 }
 
 uint64 ZLInflateFilter::tell(void)
 {
- return position;
+ return target_position;
 }
 
 uint64 ZLInflateFilter::size(void)
 {
  if(uc_size == ~(uint64)0)
-  throw MDFN_Error(ErrnoHolder(EINVAL));
- else
-  return uc_size;
+ {
+  uint8 dummy[4096];
+
+  while(read_real(dummy, sizeof(dummy), false) == sizeof(dummy))
+  {
+   //
+  }
+
+  uc_size = position;
+ }
+
+ return uc_size;
 }
 
 void ZLInflateFilter::close(void)
@@ -233,11 +292,12 @@ uint64 ZLInflateFilter::attributes(void)
 
 void ZLInflateFilter::truncate(uint64 length)
 {
- throw MDFN_Error(ErrnoHolder(EINVAL));
+ throw MDFN_Error(EINVAL, _("Error truncating %s: %s"), vfcontext.c_str(), _("ZLInflateFilter::truncate() not implemented"));
 }
 
 void ZLInflateFilter::flush(void)
 {
- throw MDFN_Error(ErrnoHolder(EINVAL));  
+ throw MDFN_Error(EINVAL, _("Error flushing %s: %s"), vfcontext.c_str(), _("ZLInflateFilter::flush() not implemented"));
 }
 
+}
