@@ -2,7 +2,7 @@
 /* Mednafen - Multi-system Emulator                                           */
 /******************************************************************************/
 /* console.cpp:
-**  Copyright (C) 2006-2016 Mednafen Team
+**  Copyright (C) 2006-2018 Mednafen Team
 **
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
@@ -45,100 +45,145 @@ bool MDFNConsole::TextHook(const std::string &text)
 {
  WriteLine(text);
 
- return(1);
+ return true;
 }
 
-int MDFNConsole::Event(const SDL_Event *event)
+void MDFNConsole::PasteText(const std::u32string& u32text)
 {
-  switch(event->type)
-  {
-   case SDL_KEYDOWN:
-                    if(event->key.keysym.mod & KMOD_ALT)
-                     break;
-                    switch(event->key.keysym.sym)
-                    {
-		     case SDLK_HOME:
-			if(event->key.keysym.mod & KMOD_SHIFT)
-			 Scrolled = -1;
-			else
-			 kb_cursor_pos = 0;
-			break;
-		     case SDLK_END:
-			if(event->key.keysym.mod & KMOD_SHIFT)
-			 Scrolled = 0;
-			else
-			 kb_cursor_pos = kb_buffer.size();
-			break;
-
-	             case SDLK_LEFT:
-	                if(kb_cursor_pos)
-	                 kb_cursor_pos--;
-	                break;
-
-	             case SDLK_RIGHT:
-	                if(kb_cursor_pos < kb_buffer.size())
-	                 kb_cursor_pos++;
-	                break;
-
-		     case SDLK_UP: 
-			Scrolled = Scrolled + 1;
-			break;
-
-		     case SDLK_DOWN: 
-			Scrolled = std::max<int32>(0, Scrolled - 1);
-			break;
-
-		     case SDLK_PAGEUP:
-			Scrolled = (Scrolled + LastPageSize);
-			break;
-
-		     case SDLK_PAGEDOWN:
-			Scrolled = std::max<int64>(0, (int64)Scrolled - LastPageSize);
-			break;
-
-                     case SDLK_RETURN:
-                     {
-                      std::string concat_str;
-                      for(unsigned int i = 0; i < kb_buffer.size(); i++)
-                       concat_str += kb_buffer[i];
-
-		      TextHook(strdup(concat_str.c_str()));
-                      kb_buffer.clear();
-		      kb_cursor_pos = 0;
-                     }
-                     break;
-	           case SDLK_BACKSPACE:
-	                if(kb_buffer.size() && kb_cursor_pos)
-	                {
-	                  kb_buffer.erase(kb_buffer.begin() + kb_cursor_pos - 1, kb_buffer.begin() + kb_cursor_pos);
-	                  kb_cursor_pos--;
-	                }
-	                break;
-  	            case SDLK_DELETE:
-	                if(kb_buffer.size() && kb_cursor_pos < kb_buffer.size())
-	                {
-	                 kb_buffer.erase(kb_buffer.begin() + kb_cursor_pos, kb_buffer.begin() + kb_cursor_pos + 1);
-	                }
-	                break;
-                     default:
-		     if(event->key.keysym.unicode >= 0x20)
-                     {
-		      const char16_t tmp = event->key.keysym.unicode;
-	              kb_buffer.insert(kb_buffer.begin() + kb_cursor_pos, UTF16_to_UTF8(&tmp, 1));
-	              kb_cursor_pos++;
-                     }
-                     break;
-                    }
-                    break;
-  }
- return(1);
+ kb_buffer.insert(kb_cursor_pos, u32text);
+ kb_cursor_pos += u32text.size();
 }
 
-MDFN_Surface* MDFNConsole::Draw(const MDFN_PixelFormat& pformat, const int32 dim_w, const int32 dim_h, const unsigned fontid, const uint32 hex_color)
+void MDFNConsole::ProcessKBBuffer(void)
+{
+ const std::string kb_utf8 = UTF32_to_UTF8(kb_buffer); 
+ //
+ kb_buffer.clear();
+ kb_cursor_pos = 0;
+ //
+ for(size_t i = 0, begin_i = 0; i <= kb_utf8.size(); i++)
+ {
+  if(i == kb_utf8.size() || kb_utf8[i] == '\r' || kb_utf8[i] == '\n')
+  {
+   TextHook(kb_utf8.substr(begin_i, i - begin_i));
+
+   if((i + 1) < kb_utf8.size() && kb_utf8[i] == '\r' && kb_utf8[i + 1] == '\n')
+    i++;
+
+   begin_i = i + 1;
+  }
+ }
+}
+
+#define KMOD_TEST_SHIFT(mod) (!((mod) & (KMOD_CTRL | KMOD_LALT)) && ((mod) & (KMOD_SHIFT)))
+#define KMOD_TEST_CTRL(mod) (!((mod) & (KMOD_SHIFT | KMOD_LALT)) && ((mod) & (KMOD_CTRL)))
+
+bool MDFNConsole::Event(const SDL_Event *event)
+{
+ switch(event->type)
+ {
+  case SDL_TEXTINPUT:
+	if(!(SDL_GetModState() & KMOD_LALT))
+	{
+	 std::u32string u32text = UTF8_to_UTF32(event->text.text);
+	 kb_buffer.insert(kb_cursor_pos, u32text);
+	 kb_cursor_pos += u32text.size();
+	}
+	break;
+
+  case SDL_KEYDOWN:
+	if(event->key.keysym.mod & KMOD_LALT)
+	 break;
+
+	if((KMOD_TEST_CTRL(event->key.keysym.mod) && event->key.keysym.sym == SDLK_v) ||
+	   (KMOD_TEST_SHIFT(event->key.keysym.mod) && event->key.keysym.sym == SDLK_INSERT))
+	{
+	 if(SDL_HasClipboardText() == SDL_TRUE)
+ 	 {
+	  char* ctext = SDL_GetClipboardText();	// FIXME: SDL_Free() on exception
+	  if(ctext)
+	  {
+	   const std::u32string u32ctext = UTF8_to_UTF32(ctext);
+	   SDL_free(ctext);
+	   PasteText(u32ctext);
+
+	   return true;
+	  }
+	 }
+	}
+	else switch(event->key.keysym.sym)
+	{
+	 case SDLK_HOME:
+		if(event->key.keysym.mod & KMOD_SHIFT)
+		 Scrolled = -1;
+		else
+		 kb_cursor_pos = 0;
+		break;
+
+	 case SDLK_END:
+		if(event->key.keysym.mod & KMOD_SHIFT)
+		 Scrolled = 0;
+		else
+		 kb_cursor_pos = kb_buffer.size();
+		break;
+
+	 case SDLK_LEFT:
+		if(kb_cursor_pos)
+		 kb_cursor_pos--;
+		break;
+
+	 case SDLK_RIGHT:
+		if(kb_cursor_pos < kb_buffer.size())
+		 kb_cursor_pos++;
+		break;
+
+	 case SDLK_UP: 
+		Scrolled = Scrolled + 1;
+		break;
+
+	 case SDLK_DOWN: 
+		Scrolled = std::max<int32>(0, Scrolled - 1);
+		break;
+
+	 case SDLK_PAGEUP:
+		Scrolled = (Scrolled + LastPageSize);
+		break;
+
+	 case SDLK_PAGEDOWN:
+		Scrolled = std::max<int64>(0, (int64)Scrolled - LastPageSize);
+		break;
+
+	 case SDLK_RETURN:
+		ProcessKBBuffer();
+		break;
+
+	 case SDLK_BACKSPACE:
+		if(kb_buffer.size() && kb_cursor_pos)
+		{
+		 kb_buffer.erase(kb_cursor_pos - 1, 1);
+		 kb_cursor_pos--;
+		}
+		break;
+
+	 case SDLK_DELETE:
+		if(kb_buffer.size() && kb_cursor_pos < kb_buffer.size())
+		{
+		 kb_buffer.erase(kb_cursor_pos, 1);
+		}
+		break;
+	}
+	break;
+ }
+
+ return false;
+}
+
+MDFN_Surface* MDFNConsole::Draw(const MDFN_PixelFormat& pformat, const int32 dim_w, const int32 dim_h, const unsigned fontid, const uint32 hex_color) //, const uint32 hex_cursorcolor)
 {
  const int32 font_height = GetFontHeight(fontid);
  const uint32 color = pformat.MakeColor((hex_color >> 16) & 0xFF, (hex_color >> 8) & 0xFF, (hex_color >> 0) & 0xFF, 0xFF);
  const uint32 shadcolor = pformat.MakeColor(0x00, 0x00, 0x01, 0xFF);
+ //const uint32 cursorcolor = pformat.MakeColor((hex_cursorcolor >> 16) & 0xFF, (hex_cursorcolor >> 8) & 0xFF, (hex_cursorcolor >> 0) & 0xFF, 0xFF);
  bool scroll_resync = false;
  bool draw_scrolled_notice = false;
 
@@ -156,7 +201,7 @@ MDFN_Surface* MDFNConsole::Draw(const MDFN_PixelFormat& pformat, const int32 dim
    scroll_resync = true;
  }
 
- if(!surface || surface->w != dim_w || surface->h != dim_h || memcmp(&surface->format, &pformat, sizeof(MDFN_PixelFormat)))
+ if(!surface || surface->w != dim_w || surface->h != dim_h || surface->format != pformat)
  {
   surface.reset(nullptr);
   surface.reset(new MDFN_Surface(nullptr, dim_w, dim_h, dim_w, pformat));
@@ -248,37 +293,26 @@ MDFN_Surface* MDFNConsole::Draw(const MDFN_PixelFormat& pformat, const int32 dim
 
  if(prompt_visible)
  {
-  std::string concat_str;
+  const unsigned space_width = GetTextPixLength(U" ");
+  std::u32string concat_str;
+  size_t concat_cursorpos = 0;
 
   if(shellstyle)
   {
    int t = TextLog.size() - 1;
    if(t >= 0)
-    concat_str = TextLog[t];
+    concat_str = UTF8_to_UTF32(TextLog[t]);
    else
-    concat_str = "";
+    concat_str = U"";
   }
   else
-   concat_str = "#>";
+   concat_str = U"#>";
 
-  for(unsigned int i = 0; i < kb_buffer.size(); i++)
-  {
-   if(i == kb_cursor_pos && (Time::MonoMS() & 0x100))
-    concat_str += "▉";
-   else
-    concat_str += kb_buffer[i];
-  }
-
-  if(kb_cursor_pos == kb_buffer.size())
-  {
-   if(Time::MonoMS() & 0x100)
-    concat_str += "▉";
-   else
-    concat_str += " ";
-  }
+  concat_cursorpos = concat_str.size() + kb_cursor_pos;
+  concat_str.append(kb_buffer);
 
   {
-   int32 nw = GetTextPixLength(concat_str.c_str()) + 1;
+   int32 nw = GetTextPixLength(concat_str.c_str()) + space_width;
 
    if(nw > tmp_surface->w)
    {
@@ -289,7 +323,18 @@ MDFN_Surface* MDFNConsole::Draw(const MDFN_PixelFormat& pformat, const int32 dim
 
   tmp_surface->Fill(0, 0, 0, opacity);
   MDFN_Rect tmp_rect, dest_rect;
-  const uint32 tpl = DrawTextShadow(tmp_surface.get(), 0, 0, concat_str, color, shadcolor, fontid);
+  const uint32 tpl = DrawTextShadow(tmp_surface.get(), 0, 0, concat_str, color, shadcolor, fontid) + space_width;
+
+  if(Time::MonoMS() & 0x100)
+  {
+   const int32 rx = GetTextPixLength(concat_str.substr(0, concat_cursorpos));
+   const int32 ry = 0;
+   const int32 rw = (concat_cursorpos < concat_str.size()) ? GetTextPixLength(concat_str.substr(concat_cursorpos, 1)) : space_width;
+   const int32 rh = GetFontHeight(fontid);
+
+   if((rx + rw) <= tmp_surface->w && (ry + rw) <= tmp_surface->h)
+    MDFN_DrawFillRect(tmp_surface.get(), rx, ry, rw, rh, /*cursor*/color);
+  }
 
   tmp_rect.x = 0;
   tmp_rect.y = 0;
