@@ -2,7 +2,7 @@
 /* Mednafen - Multi-system Emulator                                           */
 /******************************************************************************/
 /* rmdui.h:
-**  Copyright (C) 2014-2016 Mednafen Team
+**  Copyright (C) 2014-2018 Mednafen Team
 **
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
@@ -22,4 +22,5 @@
 void RMDUI_Init(MDFNGI* gi, const int which_medium) MDFN_COLD;
 void RMDUI_Kill(void) MDFN_COLD;
 void RMDUI_Toggle_InsertEject(void);
-void RMDUI_Select(void);
+void RMDUI_SelectDisk(void);
+void RMDUI_SelectDrive(void);
