@@ -442,9 +442,9 @@ static int NWC_StateAction(StateMem *sm, int load, int data_only)
 {
  SFORMAT StateRegs[] =
  {
-  SFARRAY(WRAM, WRAM_Size),
-  SFARRAY(CHRRAM, 8192),
-  SFARRAY(DRegs, 4),
+  SFPTR8(WRAM, WRAM_Size),
+  SFPTR8(CHRRAM, 8192),
+  SFPTR8(DRegs, 4),
   SFVAR(lreset),
   SFVAR(Buffer),
   SFVAR(BufferShift),
@@ -453,13 +453,18 @@ static int NWC_StateAction(StateMem *sm, int load, int data_only)
   SFEND
  };
 
+ lreset -= timestamp;
  int ret = MDFNSS_StateAction(sm, load, data_only, StateRegs, "MAPR");
+ lreset += timestamp;
+
  if(load)
  {
   MMC1MIRROR();
   MMC1CHR();
   MMC1PRG();
-  lreset=0;      /* timestamp(base) is not stored in save states. */
+
+  if(load < 0x00102101)
+   lreset = 0;
  }
  return(ret);
 }
@@ -471,22 +476,27 @@ static int StateAction(StateMem *sm, int load, int data_only)
 
  SFORMAT StateRegs[] =
  {
-  SFARRAY(WRAM, WRAM_Size),
-  SFARRAY(CHRRAM, 8192),
-  SFARRAY(DRegs, 4),
+  SFPTR8(WRAM, WRAM_Size),
+  SFPTR8(CHRRAM, 8192),
+  SFPTR8(DRegs, 4),
   SFVAR(lreset),
   SFVAR(Buffer),
   SFVAR(BufferShift),
   SFEND
  };
 
+ lreset -= timestamp;
  int ret = MDFNSS_StateAction(sm, load, data_only, StateRegs, "MAPR");
+ lreset += timestamp;
+
  if(load)
  {
   MMC1MIRROR();
   MMC1CHR();
   MMC1PRG();
-  lreset=0;      /* timestamp(base) is not stored in save states. */
+
+  if(load < 0x00102101)
+   lreset = 0;
  }
  return(ret);
 }
