@@ -534,16 +534,16 @@ int int_timer_StateAction(StateMem *sm, int load, int data_only)
  SFORMAT StateRegs[] =
  {
   SFVAR(timer_hint),
-  SFARRAY32(timer_clock, 4),
-  SFARRAY(timer, 4),
-  SFARRAY(timer_threshold, 4),
+  SFVAR(timer_clock),
+  SFVAR(timer),
+  SFVAR(timer_threshold),
   SFVAR(TRUN),
   SFVAR(T01MOD), SFVAR(T23MOD),
   SFVAR(TRDC),
   SFVAR(TFFCR),
-  SFARRAY(HDMAStartVector, 4),
-  SFARRAY32(ipending, 24),
-  SFARRAY32(IntPrio, 0xB),
+  SFVAR(HDMAStartVector),
+  SFVAR(ipending),
+  SFVAR(IntPrio),
   SFVAR(h_int),
   SFVAR(timer0),
   SFVAR(timer2),
