@@ -26,14 +26,14 @@
 #include "hes.h"
 #include <mednafen/hw_misc/arcade_card/arcade_card.h>
 #include <mednafen/mempatcher.h>
-#include <mednafen/cdrom/cdromif.h>
+#include <mednafen/cdrom/CDInterface.h>
 
 extern MDFNGI EmulatedPCE_Fast;
 
 namespace PCE_Fast
 {
 
-static std::vector<CDIF*> *cdifs = NULL;
+static std::vector<CDInterface*> *cdifs = NULL;
 static PCEFast_PSG *psg = NULL;
 extern ArcadeCard *arcade_card; // Bah, lousy globals.
 
@@ -182,9 +182,9 @@ void PCE_InitCD(void)
 static void LoadCommon(void) MDFN_COLD;
 static void LoadCommonPre(void) MDFN_COLD;
 
-static MDFN_COLD bool TestMagic(MDFNFILE *fp)
+static MDFN_COLD bool TestMagic(GameFile* gf)
 {
- if(fp->ext != "hes" && fp->ext != "pce" && fp->ext != "sgx")
+ if(gf->ext != "hes" && gf->ext != "pce" && gf->ext != "sgx")
   return false;
 
  return true;
@@ -230,7 +230,7 @@ static const struct
 	{ 0x3b13af61, "Battle Ace" },
 };
 
-static MDFN_COLD void Load(MDFNFILE *fp)
+static MDFN_COLD void Load(GameFile* gf)
 {
  try
  {
@@ -239,8 +239,8 @@ static MDFN_COLD void Load(MDFNFILE *fp)
   IsHES = false;
   IsSGX = false;
 
-  fp->read(hes_header, 4);
-  fp->seek(0, SEEK_SET);
+  gf->stream->read(hes_header, 4);
+  gf->stream->seek(0, SEEK_SET);
 
   if(!memcmp(hes_header, "HESM", 4))
    IsHES = true;
@@ -254,14 +254,14 @@ static MDFN_COLD void Load(MDFNFILE *fp)
   }
 
   if(IsHES)
-   HES_Load(fp);
+   HES_Load(gf->stream);
   else
   {
    uint32 crc;
 
-   crc = HuC_Load(fp);
+   crc = HuC_Load(gf->stream);
 
-   if(fp->ext == "sgx")
+   if(gf->ext == "sgx")
     IsSGX = true;
    else
    {
@@ -389,13 +389,13 @@ static void LoadCommon(void)
  }
 }
 
-static MDFN_COLD bool TestMagicCD(std::vector<CDIF *> *CDInterfaces)
+static MDFN_COLD bool TestMagicCD(std::vector<CDInterface*> *CDInterfaces)
 {
  static const uint8 magic_test[0x20] = { 0x82, 0xB1, 0x82, 0xCC, 0x83, 0x76, 0x83, 0x8D, 0x83, 0x4F, 0x83, 0x89, 0x83, 0x80, 0x82, 0xCC,
                                          0x92, 0x98, 0x8D, 0xEC, 0x8C, 0xA0, 0x82, 0xCD, 0x8A, 0x94, 0x8E, 0xAE, 0x89, 0xEF, 0x8E, 0xD0
                                        };
  uint8 sector_buffer[2048];
- CDIF *cdiface = (*CDInterfaces)[0];
+ CDInterface* cdiface = (*CDInterfaces)[0];
  CDUtility::TOC toc;
  bool ret = false;
 
@@ -407,7 +407,7 @@ static MDFN_COLD bool TestMagicCD(std::vector<CDIF *> *CDInterfaces)
  {
   if(toc.tracks[track].control & 0x4)
   {
-   if(cdiface->ReadSector(sector_buffer, toc.tracks[track].lba, 1) != 0x1)
+   if(cdiface->ReadSectors(sector_buffer, toc.tracks[track].lba, 1) != 0x1)
     break;
 
    if(!memcmp((char*)sector_buffer, (char *)magic_test, 0x20))
@@ -424,7 +424,7 @@ static MDFN_COLD bool TestMagicCD(std::vector<CDIF *> *CDInterfaces)
  {
   if(toc.tracks[track].control & 0x4)
   {
-   if(cdiface->ReadSector(sector_buffer, toc.tracks[track].lba, 1) == 0x1)
+   if(cdiface->ReadSectors(sector_buffer, toc.tracks[track].lba, 1) == 0x1)
    {
     if(!strncmp("PC-FX:Hu_CD-ROM", (char*)sector_buffer, strlen("PC-FX:Hu_CD-ROM")))
     {
@@ -438,7 +438,7 @@ static MDFN_COLD bool TestMagicCD(std::vector<CDIF *> *CDInterfaces)
  // data track.
  if(toc.first_track == 1 && (toc.tracks[1].control & 0x4))
  {
-  if(cdiface->ReadSector(sector_buffer, 0x10, 1) == 0x1)
+  if(cdiface->ReadSectors(sector_buffer, 0x10, 1) == 0x1)
   {
    if(!memcmp((char *)sector_buffer + 0x8, "HACKER CD ROM SYSTEM", 0x14))
    {
@@ -450,9 +450,9 @@ static MDFN_COLD bool TestMagicCD(std::vector<CDIF *> *CDInterfaces)
  return(ret);
 }
 
-static MDFN_COLD bool DetectSGXCD(std::vector<CDIF*>* CDInterfaces)
+static MDFN_COLD bool DetectSGXCD(std::vector<CDInterface*>* CDInterfaces)
 {
- CDIF *cdiface = (*CDInterfaces)[0];
+ CDInterface* cdiface = (*CDInterfaces)[0];
  CDUtility::TOC toc;
  uint8 sector_buffer[2048];
  bool ret = false;
@@ -466,7 +466,7 @@ static MDFN_COLD bool DetectSGXCD(std::vector<CDIF*>* CDInterfaces)
  {
   if(toc.tracks[track].control & 0x4)
   {
-   if(cdiface->ReadSector(sector_buffer, toc.tracks[track].lba + 1, 1) != 0x1)
+   if(cdiface->ReadSectors(sector_buffer, toc.tracks[track].lba + 1, 1) != 0x1)
     continue;
 
    if(MDFN_de64msb(&sector_buffer[0x6A]) == 0x4D65646E6166656EULL && MDFN_de64msb(&sector_buffer[0x6A + 8]) == 0x74AB901942627DE6ULL)
@@ -477,7 +477,7 @@ static MDFN_COLD bool DetectSGXCD(std::vector<CDIF*>* CDInterfaces)
  return ret;
 }
 
-static MDFN_COLD void LoadCD(std::vector<CDIF *> *CDInterfaces)
+static MDFN_COLD void LoadCD(std::vector<CDInterface*> *CDInterfaces)
 {
  try
  {
@@ -655,8 +655,7 @@ void PCE_Power(void)
  }
 }
 
-static bool SetMedia(uint32 drive_idx, uint32 state_idx, uint32 media_idx, uint32 orientation_idx) MDFN_COLD;
-static bool SetMedia(uint32 drive_idx, uint32 state_idx, uint32 media_idx, uint32 orientation_idx)
+static MDFN_COLD void SetMedia(uint32 drive_idx, uint32 state_idx, uint32 media_idx, uint32 orientation_idx)
 {
  const RMD_Layout* rmd = EmulatedPCE_Fast.RMD;
  const RMD_Drive* rd = &rmd->Drives[drive_idx];
@@ -670,13 +669,10 @@ static bool SetMedia(uint32 drive_idx, uint32 state_idx, uint32 media_idx, uint3
  {
   PCECD_Drive_SetDisc(rs->MediaCanChange, NULL);
  }
-
- return(true);
 }
 
 
-static void DoSimpleCommand(int cmd) MDFN_COLD;
-static void DoSimpleCommand(int cmd)
+static MDFN_COLD void DoSimpleCommand(int cmd)
 {
  switch(cmd)
  {
@@ -714,10 +710,11 @@ static uint8 MemRead(uint32 addr)
 
 static const FileExtensionSpecStruct KnownExtensions[] =
 {
- { ".pce", gettext_noop("PC Engine ROM Image") },
- { ".hes", gettext_noop("PC Engine Music Rip") },
- { ".sgx", gettext_noop("SuperGrafx ROM Image") },
- { NULL, NULL }
+ { ".pce",   0, gettext_noop("PC Engine ROM Image") },
+ { ".hes", -20, gettext_noop("PC Engine Music Rip") },
+ { ".sgx",   0, gettext_noop("SuperGrafx ROM Image") },
+
+ { NULL, 0, NULL }
 };
 
 static const CustomPalette_Spec CPInfo[] =
