@@ -24,7 +24,7 @@
 
 namespace MDFN_IEN_PSX
 {
-InputDevice *Device_DualShock_Create(void);
+InputDevice *Device_DualShock_Create(void) MDFN_COLD;
 extern const IDIISG Device_DualShock_IDII;
 }
 #endif
