@@ -25,7 +25,7 @@
 namespace MDFN_IEN_PSX
 {
 
-InputDevice *Device_Justifier_Create(void);
+InputDevice *Device_Justifier_Create(void) MDFN_COLD;
 extern IDIISG Device_Justifier_IDII;
 
 }
