@@ -4,7 +4,7 @@
 namespace MDFN_IEN_SMS
 {
 
-void Cart_Init(MDFNFILE *fp) MDFN_COLD;
+void Cart_Init(GameFile* gf) MDFN_COLD;
 void Cart_Close(void) MDFN_COLD;
 
 void Cart_Reset(void);
