@@ -2,7 +2,7 @@
 /* Mednafen Fast SNES Emulation Module                                        */
 /******************************************************************************/
 /* ppu.h:
-**  Copyright (C) 2015-2016 Mednafen Team
+**  Copyright (C) 2015-2017 Mednafen Team
 **
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
@@ -25,16 +25,17 @@
 namespace MDFN_IEN_SNES_FAUST
 {
 
-void PPU_Init(void);
-void PPU_Kill(void);
-void PPU_Reset(bool powering_up);
+void PPU_Init(const bool IsPAL) MDFN_COLD;
+void PPU_SetGetVideoParams(MDFNGI* gi, const bool caspect) MDFN_COLD;
+void PPU_Kill(void) MDFN_COLD;
+void PPU_Reset(bool powering_up) MDFN_COLD;
 void PPU_ResetTS(void);
 
 void PPU_StateAction(StateMem* sm, const unsigned load, const bool data_only);
 
 void PPU_StartFrame(EmulateSpecStruct* espec);
 
-uint32 PPU_Update(uint32 timestamp);
+uint32 PPU_Update(uint32 timestamp) MDFN_HOT;
 
 }
 
