@@ -106,8 +106,8 @@ void IODevice_Multitap::StateAction(StateMem* sm, const unsigned load, const boo
 {
  SFORMAT StateRegs[] =
  {
-  SFARRAY(sub_state, 6),
-  SFARRAY(tmp, 4),
+  SFVAR(sub_state),
+  SFVAR(tmp),
   SFVAR(id1),
   SFVAR(id2),
 
@@ -138,7 +138,7 @@ void IODevice_Multitap::StateAction(StateMem* sm, const unsigned load, const boo
  }
 }
 
-enum { PhaseBias = __COUNTER__ + 1 };
+enum : int { PhaseBias = __COUNTER__ + 1 };
 
 #define WAIT_UNTIL(cond)  {					\
 			    case __COUNTER__:				\
