@@ -37,7 +37,7 @@ static NO_INLINE NO_CLONE void JMPInstr(void)
   DSP.PC = (uint8)instr;
 }
 
-void (*DSP_JMPFuncTable[2][128])(void) =
+extern void (*const DSP_JMPFuncTable[2][128])(void) =
 {
  #include "scu_dsp_jmptab.inc"
 };
