@@ -17,21 +17,26 @@
 //
 //
 //
-
-#ifdef __USING_SJLJ_EXCEPTIONS__
- #error "SJLJ-style exception handling will incur a significant performance penalty even when exceptions are not thrown, and thus an alternative(e.g. DWARF) should be used if at all possible."
-#endif
-
-#if defined(__PIC__) || defined(__pic__) || defined(__PIE__) || defined(__pie__)
- #if defined(__386__) || defined(__i386__) || defined(__i386) || defined(_M_IX86) || defined(_M_I386) //|| (SIZEOF_VOID_P <= 4)
-  #error "Compiling with position-independent code generation enabled is not recommended, for performance reasons."
- #else
+#ifndef MDFN_DISABLE_PICPIE_ERRWARN
+ #if defined(__PIC__) || defined(__pic__) || defined(__PIE__) || defined(__pie__)
   #warning "Compiling with position-independent code generation enabled is not recommended, for performance reasons."
  #endif
 #endif
 
-#if defined(__x86_64__) && defined(__code_model_large__)
- #error "Compiling with large memory model is not recommended, for performance reasons."
+#ifndef MDFN_DISABLE_NO_OPT_ERRWARN
+ #if defined(__GNUC__)
+  #if !defined(__OPTIMIZE__) && !defined(__OPTIMIZE_SIZE__)
+   #warning "Compiling without optimizations."
+  #endif
+
+  #if defined(__x86_64__) && defined(__code_model_large__)
+   #error "Compiling with large memory model is not recommended, for performance reasons."
+  #endif
+ #endif
+
+ #ifdef __USING_SJLJ_EXCEPTIONS__
+  #error "SJLJ-style exception handling will incur a significant performance penalty even when exceptions are not thrown, and thus an alternative(e.g. DWARF) should be used if at all possible."
+ #endif
 #endif
 //
 //
