@@ -1,2 +1,6 @@
+namespace Mednafen
+{
+
 bool MDFN_ResizeSurface(const MDFN_Surface *src, const MDFN_Rect *src_rect, const int32 *LineWidths, MDFN_Surface *dest, const MDFN_Rect *dest_rect);
 
+}
